#!/bin/sh

TMPDIR="$(mktemp -d)"
DATE="$(date '+%Y-%m-%d--%H-%M-%S')"

sudo echo "Sampling running PhotoLab application... \c"
mkdir "$TMPDIR/Sample"
for i in 3 4 5; do
  sudo /usr/bin/sample DXOPhotoLab$i -f "$TMPDIR/Sample/sample$i.log" 2>/dev/null
done
echo "done."

echo "Collecting application logs and diagnostics... \c"
sudo log show --last 1d --predicate 'subsystem beginswith "com.dxo."' > "$TMPDIR/DOPLog.log"
/bin/cp /private/var/log/system.log "$TMPDIR/" 2>/dev/null
echo "done."

echo "Collecting crashes... \c"
CRASHES_DIR="$TMPDIR/Crashes"
mkdir "$CRASHES_DIR"
/bin/cp ~/Library/Logs/DiagnosticReports/*PhotoLab*.crash "$CRASHES_DIR/" 2>/dev/null
/bin/cp ~/Library/Logs/DiagnosticReports/*XPCCor*.crash "$CRASHES_DIR/" 2>/dev/null
/bin/cp ~/Library/Logs/DiagnosticReports/*Photos*.crash "$CRASHES_DIR/" 2>/dev/null
echo "done."

echo "Collecting PhotoLab preferences... \c"
cp ~/Library/Application\ Support/DxO\ Labs/DxOUserID "$TMPDIR/" 2>/dev/null
PREFS_DIR="$TMPDIR/Preferences"
mkdir "$PREFS_DIR"
MANIFEST_FILE="$TMPDIR/DxOPhotoLab_manifest.txt"
/usr/bin/touch "$MANIFEST_FILE"
for i in 3 4 5; do
  /bin/cp ~/Library/Preferences/com.dxo.PhotoLab$i.plist "$PREFS_DIR/" 2>/dev/null
  /bin/cp ~/Library/Preferences/com.dxo.photolab$i.workspace.plist "$PREFS_DIR/" 2>/dev/null
  /bin/cp ~/Library/DxO\ PhotoLab\ v$i/OutputSettings.plist "$PREFS_DIR/OutputSettings$i.plist" 2>/dev/null
  if [ -e ~/Library/DxO\ PhotoLab\ v$i ]
  then
    echo "$HOME/Library/DxO PhotoLab v$i:" >> "$MANIFEST_FILE"
    /bin/ls -lR ~/Library/DxO\ PhotoLab\ v$i >> "$MANIFEST_FILE"
  fi
  if [ -e ~/Library/DxO\ PhotoLab\ v$i/DOPDatabaseV$i.dopdata ]
  then
    echo "\nDOPDatabaseV$i metadata:" >> "$MANIFEST_FILE"
    /usr/bin/sqlite3 ~/Library/DxO\ PhotoLab\ v$i/DOPDatabaseV$i.dopdata 'select quote(Z_PLIST) from Z_METADATA' | /usr/bin/cut -d\' -f2 | /usr/bin/xxd -r -p | /usr/bin/plutil -p - >> "$MANIFEST_FILE"
  fi
  echo "\n=====\n" >> "$MANIFEST_FILE"
done
echo "done."

echo "Gathering hardware specifications... \c"
/usr/sbin/diskutil info -all > "$TMPDIR/diskutil_info.txt" 2>/dev/null
/usr/sbin/system_profiler -xml > "$TMPDIR/SystemProfile.spx" 2>/dev/null
echo "done."

echo "Generating archive..."
/usr/bin/find "$TMPDIR" -empty -delete
cd "$TMPDIR/" && zip -r "$HOME/Desktop/DxODiagnosticData-$DATE" *
echo "Archive 'DxODiagnosticData-$DATE.zip' has been created on your Desktop."
